# matheo

Matheo is a python package with mathematical algorithms for use in Earth observation data and tools.


## Installation

matheo is installable via pip.

## Documentation

For more information visit our [documentation](https://matheo.readthedocs.io/en/latest).

## License

matheo is free software licensed under the
[GNU Lesser Public License (v3)](./LICENSE).

## Acknowledgements

matheo was written by Sam Hunt, Mattea Goalen, Maddie Stedman, Pieter De Vis.

The development has been funded by:

* The UK's Department for Business, Energy and Industrial Strategy's (BEIS) National Measurement System (NMS) programme
* The IDEAS-QA4EO project funded by the European Space Agency.

## Project status

matheo is under active development. It is beta software.